.. currentmodule:: sardana.sardanabase

:mod:`~sardana.pool.sardanabase`
=====================================

.. automodule:: sardana.sardanabase

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`SardanaBaseObject`
    * :class:`SardanaObjectID`

SardanaBaseObject
------------------

.. inheritance-diagram:: SardanaBaseObject
    :parts: 1
    
.. autoclass:: SardanaBaseObject
    :inherited-members:
    :members:
    :undoc-members:

SardanaObjectID
------------------

.. inheritance-diagram:: SardanaObjectID
    :parts: 1
    
.. autoclass:: SardanaObjectID
    :inherited-members:
    :members:
    :undoc-members: